<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Notes/language/en_us.lang.php,v 1.10 2005/03/28 06:33:37 rank Exp $
 * Description:  Defines the English language pack for the Documents module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Documents',
'LBL_MODULE_TITLE'=>'Documents: Home',
'LBL_SEARCH_FORM_TITLE'=>'Document Search',
'LBL_LIST_FORM_TITLE'=>'Document List',
'LBL_NEW_FORM_TITLE'=>'New Document',

'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_CONTACT_NAME'=>'Contact Name',
'LBL_LIST_RELATED_TO'=>'Related To',
'LBL_LIST_DATE_MODIFIED'=>'Last Modified',

'LBL_NOTE'=>'Document:',
'LBL_NOTE_SUBJECT'=>'Document Subject:',
'LBL_CONTACT_NAME'=>'Contact Name:',
'LBL_PHONE'=>'Phone:',
'LBL_SUBJECT'=>'Subject:',
'LBL_CLOSE'=>'Close:',
'LBL_RELATED_TO'=>'Related To:',
'LBL_EMAIL_ADDRESS'=>'Email Address:',
'LBL_COLON'=>':',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the vtiger_account.",
'LBL_LIST_FILENAME'=>"File Name",

// Added for Note(3.2-patch 3) 

'LBL_FILENAME'=>'Attachment:',
'LBL_NOTE_INFORMATION'=>'Basic Information',
'File Information'=>'File Information',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Documents Tools',
// Added for 4GA
'Contact Name'=>'Contact Name',
'Related To'=>'Related to',
'Subject'=>'Subject',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Document'=>'Document',
'Note'=>'Notes',
//Added for 4.2 Release -- CustomView
'Related to'=>'Related to',
'Last Modified'=>'Last Modified',
'File'=>'File',
'LBL_ALL'=>'All',
'Title'=>'Title',

//Added after 504 for Downloads Module
'LBL_FILE_INFORMATION'=>'File Information',
'LBL_FILE_NAME'=>'File Name',
'LBL_FILE_TYPE'=>'File Type',
'LBL_FILE_SIZE'=>'Size',
'filelocationtype'=>'Download Type',
'fileversion'=>'Version',
'filestatus'=>'Active',
'filedownloadcount'=>'Download Count',
'os'=>'Platform',
'LBL_FOLDER_NAME'=>'Folder Name',
'LBL_DOWNLOAD_TYPE'=>'Download Type',
'LBL_INTERNAL'=>'Internal',
'LBL_EXTERNAL'=>'External',
'LBL_EXTERNAL_FILE_NAME'=>'File Name',
'LBL_FILE_LOCATION'=>'File Location',
'LBL_PD'=>'Platform Dependent',
'LBL_PIND'=>'Platform Independent',
'ChoosePlatform'=>'Choose Platform',
'LBL_ACTIVE'=>'Active',
'LBL_INACTIVE'=>'Inactive',
'LBL_UPLOAD_BUTTON'=>'Upload',
'architecture'=>'Architecture',
'LBL_DOWNLOAD_FILE'=>'Download file',
'LBL_CHECK_INTEGRITY'=>'Check file integrity',
'LBL_EMAIL_FILE'=>'Email file as attachment',
'LBL_CLICK_HERE'=>'Click here',
'LBL_TO_ADD_FOLDER'=>'to add a new folder.',
'LBL_DELETE_FOLDER'=>'Delete Folder',
'LBL_FOLDER_DESC'=>'Description',
'LBL_ADD_NEW_FOLDER'=>'Add Folder',
'LBL_DELETE_DOCUMENTS'=>'Delete Document(s)',
'LBL_MOVE_TO'=>'Move to',
'File Name'=>'File Name',
'File Type'=>'File Type',
'File Size'=>'Size',
'LBL_INTERNAL'=>'Internal',
'LBL_URL'=>'URL',
'LBL_EXTERNAL'=>'External',
'LBL_EXTERNAL_LNK'=>'External Link',
'LBL_ACTIVE'=>'Active',
'LBL_INACTIVE'=>'Inactive',
'LBL_PLATFORM_INDEPENDENT'=>'Platform Independent',
'LNK_DOWNLOAD'=>'download',
'LBL_MOVE_DOCUMENTS'=>'Move Document(s)',
'LBL_MOVE'=>'Move',
'Download Type'=>'Download Type',
'Version'=>'Version',
'Active'=>'Active',
'Download Count'=>'Download Count',
'Platform'=>'Platform',
'Assigned To'=>'Assigned To',
// Module Sequence Numbering
'Note No' => 'Document No',
// END

// Documents module
'LBL_EMPTY_FOLDERS' => 'Empty Folders',
'LBL_VIEW_EMPTY_FOLDERS' => 'View Empty Folders',
'LBL_NO_DOCUMENTS' => 'No Documents',
'LBL_DESCRIPTION' => 'Description',
'FILE_HAS_NO_DATA'=>'The selected file has no data or a invalid file',

'LBL_MAXIMUM_20'=>'Maximum 20',
'LBL_MAXIMUM_50'=>'Maximum 50',

// Added after 5.1.0 GA
'Folder Name'=>'Folder Name',
'Document No'=>'Document No',

'Documents' => 'Documents',
'Documents ID' => 'Documents ID',
);

?>
